[FFmpeg-devel] [PATCH] avcodec/ass_split: Rename ff_ass_split_dialog2->ff_ass_split_dialog

Andreas Rheinhardt andreas.rheinhardt at outlook.com
Sun Aug 8 00:54:26 EEST 2021


Signed-off-by: Andreas Rheinhardt <andreas.rheinhardt at outlook.com>
---
This is in reply to James' opinion here:
https://ffmpeg.org/pipermail/ffmpeg-devel/2021-August/283267.html

 libavcodec/ass_split.c  | 2 +-
 libavcodec/ass_split.h  | 4 ++--
 libavcodec/movtextenc.c | 2 +-
 libavcodec/srtenc.c     | 2 +-
 libavcodec/ttmlenc.c    | 2 +-
 libavcodec/webvttenc.c  | 2 +-
 6 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/libavcodec/ass_split.c b/libavcodec/ass_split.c
index eb7ff2845a..05c5453e53 100644
--- a/libavcodec/ass_split.c
+++ b/libavcodec/ass_split.c
@@ -424,7 +424,7 @@ void ff_ass_free_dialog(ASSDialog **dialogp)
     av_freep(dialogp);
 }
 
-ASSDialog *ff_ass_split_dialog2(ASSSplitContext *ctx, const char *buf)
+ASSDialog *ff_ass_split_dialog(ASSSplitContext *ctx, const char *buf)
 {
     int i;
     static const ASSFields fields[] = {
diff --git a/libavcodec/movtextenc.c b/libavcodec/movtextenc.c
index a6a1808592..2ae5a9bf0b 100644
--- a/libavcodec/movtextenc.c
+++ b/libavcodec/movtextenc.c
@@ -654,7 +654,7 @@ static int mov_text_encode_frame(AVCodecContext *avctx, unsigned char *buf,
             return AVERROR(EINVAL);
         }
 
-        dialog = ff_ass_split_dialog2(s->ass_ctx, ass);
+        dialog = ff_ass_split_dialog(s->ass_ctx, ass);
         if (!dialog)
             return AVERROR(ENOMEM);
         mov_text_dialog(s, dialog);
diff --git a/libavcodec/srtenc.c b/libavcodec/srtenc.c
index edc91c4013..2e3ac55770 100644
--- a/libavcodec/srtenc.c
+++ b/libavcodec/srtenc.c
@@ -245,7 +245,7 @@ static int encode_frame(AVCodecContext *avctx,
             return AVERROR(EINVAL);
         }
 
-        dialog = ff_ass_split_dialog2(s->ass_ctx, ass);
+        dialog = ff_ass_split_dialog(s->ass_ctx, ass);
         if (!dialog)
             return AVERROR(ENOMEM);
         s->alignment_applied = 0;
diff --git a/libavcodec/ttmlenc.c b/libavcodec/ttmlenc.c
index 5cab33cc60..ad2eddfdd5 100644
--- a/libavcodec/ttmlenc.c
+++ b/libavcodec/ttmlenc.c
@@ -95,7 +95,7 @@ static int ttml_encode_frame(AVCodecContext *avctx, uint8_t *buf,
             return AVERROR(EINVAL);
         }
 
-        dialog = ff_ass_split_dialog2(s->ass_ctx, ass);
+        dialog = ff_ass_split_dialog(s->ass_ctx, ass);
         if (!dialog)
             return AVERROR(ENOMEM);
 
diff --git a/libavcodec/webvttenc.c b/libavcodec/webvttenc.c
index 3181e25120..89b49e42bf 100644
--- a/libavcodec/webvttenc.c
+++ b/libavcodec/webvttenc.c
@@ -172,7 +172,7 @@ static int webvtt_encode_frame(AVCodecContext *avctx,
             return AVERROR(EINVAL);
         }
 
-        dialog = ff_ass_split_dialog2(s->ass_ctx, ass);
+        dialog = ff_ass_split_dialog(s->ass_ctx, ass);
         if (!dialog)
             return AVERROR(ENOMEM);
         webvtt_style_apply(s, dialog->style);
diff --git a/libavcodec/ass_split.h b/libavcodec/ass_split.h
index 2ce756203e..a45fb9b8a1 100644
--- a/libavcodec/ass_split.h
+++ b/libavcodec/ass_split.h
@@ -110,7 +110,7 @@ typedef struct ASSSplitContext ASSSplitContext;
 ASSSplitContext *ff_ass_split(const char *buf);
 
 /**
  * Free a dialogue obtained from ff_ass_split_dialog2().
  */
 void ff_ass_free_dialog(ASSDialog **dialogp);
 
@@ -121,7 +121,7 @@ void ff_ass_free_dialog(ASSDialog **dialogp);
  * @param buf String containing the ASS "Dialogue" line.
  * @return Pointer to the split ASSDialog. Must be freed with ff_ass_free_dialog()
  */
-ASSDialog *ff_ass_split_dialog2(ASSSplitContext *ctx, const char *buf);
+ASSDialog *ff_ass_split_dialog(ASSSplitContext *ctx, const char *buf);
 
 /**
  * Free all the memory allocated for an ASSSplitContext.
@@ -110,7 +110,7 @@ typedef struct ASSSplitContext ASSSplitContext;
 
 /**
- * Free a dialogue obtained from ff_ass_split_dialog2().
+ * Free a dialogue obtained from ff_ass_split_dialog().
  */
 void ff_ass_free_dialog(ASSDialog **dialogp);
-- 
2.30.2



More information about the ffmpeg-devel mailing list